#!/usr/bin/env python
# encoding: utf-8
"""
An example config file using bin / tuple functionality to generate a 
report on CrIS SDR spectra.

Created by Eva Schiffer Jun 2010.
Copyright (c) 2010 University of Wisconsin SSEC. All rights reserved.
"""

# you will need to import the glance.constants to get the standard names
import glance.constants as constants

# various general settings to control how reports are created
settings = {}
settings[constants.DO_MAKE_IMAGES_KEY] = True

# no latitude and longitude variables that will be used
lat_lon_info = {}

# there is rogue "missing" data in some of the files I've seen that goes
# below -999.0; this function will standardize the missing data values
def temp_set_missing_fn (data, lowBound, missingValue) :
   """
   call this function with:

   data         - the data to clean up
   lowBound     - the lowest value that does not need to be cleaned up
   missingValue - the value that should be used for "fill" data
   """
   data[data < lowBound] = missingValue

   return data

# per variable defaults
defaultValues = {
                constants.BIN_INDEX_KEY:   2,
                constants.BIN_NAME_KEY:    'detector',
                constants.TUPLE_INDEX_KEY: 3,
                constants.TUPLE_NAME_KEY:  'wave number',

                constants.FILL_VALUE_KEY: -999.3,

                # you can optionally use these filters if you're seeing weird below range data
#                constants.FILTER_FUNCTION_A_KEY: (lambda data: temp_set_missing_fn(data, -990.0, -999.0)),
#                constants.FILTER_FUNCTION_B_KEY: (lambda data: temp_set_missing_fn(data, -990.0, -999.0))
                }

# a list of all the variables to analyze
setOfVariables = {}

setOfVariables['Imaginary Long Wave'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'All_Data/CrIS-SDR_All/ESImaginaryLW'
}

setOfVariables['Imaginary Medium Wave'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'All_Data/CrIS-SDR_All/ESImaginaryMW'
}

setOfVariables['Imaginary Short Wave'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'All_Data/CrIS-SDR_All/ESImaginarySW'
}

setOfVariables['Real Long Wave'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'All_Data/CrIS-SDR_All/ESRealLW'
}

setOfVariables['Real Medium Wave'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'All_Data/CrIS-SDR_All/ESRealMW'
}

setOfVariables['Real Short Wave'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'All_Data/CrIS-SDR_All/ESRealSW'
}