#!/usr/bin/env python
# encoding: utf-8
"""
A Glance config file to compare two Geocat output files at different resolutions, where
File A is exactly twice the res of File B. Created to compare L1 files generated from HSD
and HimawariCast data.

Created by Graeme Martin 2016-03-13.
Copyright (c) 2016 University of Wisconsin SSEC. All rights reserved.
"""

# you will need to import the glance.constants to get the standard names
import glance.constants as constants

# general settings to control how reports are created
settings = {}
settings[constants.DO_CLEAR_MEM_THREADED_KEY] = True
settings[constants.DO_MAKE_IMAGES_KEY]        = True
settings[constants.USE_SHARED_ORIG_RANGE_KEY] = False
settings[constants.DO_MAKE_FORKS_KEY]         = False

# info on the latitude and longitude variables that will be used
lat_lon_info = {}
lat_lon_info[constants.LON_LAT_EPSILON_KEY] = 0.0001

# the striding filter
stride2Filter1d = (lambda data:data[::2])
stride2Filter2d = (lambda data:data[::2,::2])

# per variable defaults
defaultValues = {}

# a list of all the variables to analyze
#
# If you wish to analyze all possible variables,
# do not place any entries in the setOfVariables (ie. just
# leave it as an empty dictionary)
setOfVariables = {}

setOfVariables['ch 2 refl'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_2_reflectance',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 3 refl'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_3_reflectance',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 5 refl'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_5_reflectance',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 6 refl'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_6_reflectance',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 7 refl'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_7_reflectance',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 7 emiss'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_7_emissivity',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 7 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_7_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 8 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_8_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 9 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_9_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 10 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_10_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 11 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_11_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 12 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_12_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 13 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_13_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 14 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_14_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 15 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_15_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['ch 16 bt'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_16_brightness_temperature',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['eco type'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_ecosystem_type',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['latitude'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_latitude',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['longitude'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_longitude',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['relaz'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_relative_azimuth_angle',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['satzen'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_satellite_zenith_angle',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['solzen'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_solar_zenith_angle',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['sfc type'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_surface_type',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter2d
    }

setOfVariables['bc1 planck'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'bc1_planck'
    }

setOfVariables['bc2 planck'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'bc2_planck'
    }

setOfVariables['cal offset'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'calibration_offset'
    }

setOfVariables['cal slope'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'calibration_slope'
    }

setOfVariables['cal slope degrade'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'calibration_slope_degrade'
    }

setOfVariables['cal solar const'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'calibration_solar_constant'
    }

setOfVariables['channel wavenumber'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'channel_wavenumber'
    }

setOfVariables['fk1 planck'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'fk1_planck'
    }

setOfVariables['fk2 planck'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'fk2_planck'
    }

setOfVariables['scan line time'] = {
    constants.VARIABLE_TECH_NAME_KEY: 'scan_line_time',
    constants.FILTER_FUNCTION_A_KEY: stride2Filter1d
    }