#!/usr/bin/env python
# encoding: utf-8
"""
An example config file for Geocat Level 1 files, filtered by 
satellite zenith angle <= 70

The satellite zenith angle filter is applied to pixel resolution variables, 
and not applied to other variables.

Created by Graeme Martin 2010-02-16.
Copyright (c) 2010 University of Wisconsin SSEC. All rights reserved.
"""

# you will need to import the glance.constants to get the standard names
import glance.constants as constants

import glance.filters as filters

# this is the filter that will handle checking our satellite zenith angles
satzenFilter = (lambda data, filterData: 
                    filters.filter_based_on_additional_data_set_min_max_bounds(data, 
                    filterData, missingValue=-32768, minOkFilterValue=-100, 
                    maxOkFilterValue=70))

# general settings to control how reports are created
settings = {}
settings[constants.DO_CLEAR_MEM_THREADED_KEY] = True
settings[constants.DO_MAKE_IMAGES_KEY]        = True
settings[constants.DO_MAKE_FORKS_KEY]         = False

# info on the latitude and longitude variables that will be used
lat_lon_info = {}
lat_lon_info[constants.LON_LAT_EPSILON_KEY]  = 0.0001



# per variable defaults
defaultValues = {}

# a list of all the variables to analyze
#
# If you wish to analyze all possible variables,
# do not place any entries in the setOfVariables (ie. just
# leave it as an empty dictionary)
setOfVariables = {}

setOfVariables['ch 16 bt'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_16_brightness_temperature',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['fk2 planck'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'fk2_planck'
    }

setOfVariables['relaz'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_relative_azimuth_angle',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['ch 5 refl'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_5_reflectance',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['fk1 planck'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'fk1_planck'
    }

setOfVariables['ch 10 bt'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_10_brightness_temperature',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['ch 7 bt'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_7_brightness_temperature',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['lon'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_longitude',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['surface type'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_surface_type',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['eco type'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_ecosystem_type',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['cal slope'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'calibration_slope'
    }

setOfVariables['cal slope degrade'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'calibration_slope_degrade'
    }

setOfVariables['ch 12 bt'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_12_brightness_temperature',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['ch 2 refl'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_2_reflectance',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['ch 7 refl'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_7_reflectance',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['ch 15 bt'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_15_brightness_temperature',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['ch 8 bt'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_8_brightness_temperature',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['cal offset'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'calibration_offset'
    }

setOfVariables['bc1 planck'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'bc1_planck'
    }

setOfVariables['ch 11 bt'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_11_brightness_temperature',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['ch 14 bt'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_14_brightness_temperature',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['solzen'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_solar_zenith_angle',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['lat'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_latitude',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['bc2 planck'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'bc2_planck'
    }

setOfVariables['cal solar const'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'calibration_solar_constant'
    }

setOfVariables['ch 7 emiss'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_7_emissivity',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['channel wavenumber'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_wavenumber'
    }

setOfVariables['ch 3 refl'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'channel_3_reflectance',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }

setOfVariables['satzen'] = {
    # this entry should correspond to the name in the data file
    constants.VARIABLE_TECH_NAME_KEY: 'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_A_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_NAME_B_KEY:'pixel_satellite_zenith_angle',
    constants.VAR_FILTER_FUNCTION_A_KEY: satzenFilter,
    constants.VAR_FILTER_FUNCTION_B_KEY: satzenFilter
    }


